"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDownloadFileByExactKeyPlugins = void 0;
var _s = _interopRequireDefault(require("aws-sdk/clients/s3"));
var _utils = require("../utils");
var _gateway = require("@webiny/handler-aws/gateway");
var _getS3Object = require("./getS3Object");
var _extractFileInformation = require("./extractFileInformation");
const DEFAULT_CACHE_MAX_AGE = 30758400; // 1 year
const PRESIGNED_URL_EXPIRATION = 900; // 15 minutes

const {
  region
} = (0, _utils.getEnvironment)();
const s3 = new _s.default({
  region
});
const createDownloadFileByExactKeyPlugins = () => {
  return [new _gateway.RoutePlugin(({
    onGet,
    context
  }) => {
    onGet("/files/*", async (request, reply) => {
      const fileInfo = (0, _extractFileInformation.extractFileInformation)(request);
      const {
        params,
        object
      } = await (0, _getS3Object.getS3Object)(fileInfo, s3, context);
      if (object && (0, _getS3Object.isSmallObject)(object)) {
        console.log("This is a small file; responding with object body.");
        return reply.headers({
          "Content-Type": object.ContentType,
          "Cache-Control": `public, max-age=${DEFAULT_CACHE_MAX_AGE}`,
          "x-webiny-base64-encoded": true
        }).send(object.Body || "");
      }
      console.log("This is a large object; redirecting to a presigned URL.");
      const presignedUrl = s3.getSignedUrl("getObject", {
        Bucket: params.Bucket,
        Key: params.Key,
        Expires: PRESIGNED_URL_EXPIRATION
      });

      // Lambda can return max 6MB of content, so if our object's size is larger, we are sending
      // a 301 Redirect, redirecting the user to the public URL of the object in S3.
      return reply.code(301).headers({
        Location: presignedUrl,
        "Cache-Control": "public, max-age=" + PRESIGNED_URL_EXPIRATION
      }).send("");
    });
  })];
};
exports.createDownloadFileByExactKeyPlugins = createDownloadFileByExactKeyPlugins;

//# sourceMappingURL=byExactKey.js.map